import React, { FC } from 'react';
import Svg, { Path } from 'react-native-svg';
import { defaultColors } from '../../../constants';
import { SvgProps } from '../icon.model';
import { Animated, Easing } from 'react-native';

const SPEED = '600deg';

export const SpinnerIcon: FC<SvgProps> = ({
  width = '24',
  height = '24',
  color = defaultColors.text?.default,
  style,
  ...props
}) => {
  const rotateValueHolder = new Animated.Value(0);

  Animated.loop(
    Animated.timing(rotateValueHolder, {
      toValue: 1,
      duration: 3000,
      easing: Easing.linear,
      useNativeDriver: false,
    }),
  ).start();

  const rotateData = rotateValueHolder.interpolate({
    inputRange: [0, 1],
    outputRange: ['0deg', SPEED],
  });

  return (
    <Animated.View
      style={{
        transform: [{ rotate: rotateData }],
      }}
    >
      <Svg
        width={width}
        height={height}
        style={style}
        testID={'Spinner'}
        viewBox={'0 0 24 24'}
        fill={'none'}
        {...props}
      >
        <Path
          d='M13.111 3.111v2.963a1.111 1.111 0 01-2.222 0V3.111a1.111 1.111 0 012.222 0zm7.778 7.778h-2.963a1.111 1.111 0 000 2.222h2.963a1.111 1.111 0 000-2.222zm-3.913 4.516a1.111 1.111 0 00-1.571 1.57l2.095 2.096A1.111 1.111 0 0019.07 17.5l-2.095-2.095zM12 16.815a1.111 1.111 0 00-1.111 1.11v2.964a1.111 1.111 0 002.222 0v-2.963A1.111 1.111 0 0012 16.815zm-4.976-1.41L4.93 17.5A1.111 1.111 0 006.5 19.07l2.095-2.095a1.11 1.11 0 00-1.57-1.571zM7.185 12a1.111 1.111 0 00-1.11-1.111H3.11a1.111 1.111 0 000 2.222h2.963A1.111 1.111 0 007.185 12zM6.5 4.929A1.111 1.111 0 004.93 6.5l2.095 2.095a1.111 1.111 0 001.571-1.57L6.5 4.928z'
          fill={color}
        />
      </Svg>
    </Animated.View>
  );
};
