import React, { FC } from 'react';
import { View } from 'react-native';
import { Body2RegularText, LabelRegularText, SwitchLarge } from '../../../../../atoms';
import { BinarySubtitleModel, LoadingInfoTextModel } from '../../../widgetDetailModels';
import { styles } from './styles';

interface Props {
  title?: string;
  subtitle?: BinarySubtitleModel;
  loadingInfoTextOptions?: LoadingInfoTextModel;
  value?: boolean;
  onChangeValue?: (response: boolean) => void;
  loading?: boolean;
  enabled?: boolean;
  switchVisible?: boolean;
}

export const SetThermostatSwitch: FC<Props> = ({
  title,
  subtitle,
  loadingInfoTextOptions,
  value = false,
  onChangeValue,
  loading = false,
  enabled = true,
  switchVisible = true,
}) => {
  const subtitleOn = subtitle?.on;
  const subtitleOff = subtitle?.off;
  const switchingOnInfoText = loadingInfoTextOptions?.option1;
  const switchingOffInfoText = loadingInfoTextOptions?.option2;
  const adjustingInfoText = loadingInfoTextOptions?.option3;

  const getLoadingMessage  = () => {
    if (!enabled && value) {
      return switchingOffInfoText;
    }
    if (enabled) {
      return value ? switchingOnInfoText : adjustingInfoText;
    }
  };

  return (
    <View style={styles.setSwitchWrapper}>
      <View style={styles.setSwitchContent}>
        <LabelRegularText numberOfLines={1}>{title}</LabelRegularText>
        {loading && (
          <Body2RegularText color={styles.setSwitchContent.color}>
            {getLoadingMessage()}
          </Body2RegularText>
        )}
        {!loading && (
          <Body2RegularText color={styles.setSwitchContent.color}>
            {enabled ? subtitleOn : subtitleOff}
          </Body2RegularText>
        )}
      </View>
      {switchVisible &&
        <SwitchLarge
          disabled={loading}
          loading={loading}
          onValueChange={() => onChangeValue?.(!value)}
          value={enabled}
        />
      }
    </View>
  );
};
