import React, { FC } from 'react';
import { View } from 'react-native';
import { styles } from './styles';
import { ThermostatSwitchHeader } from './components/thermostat/switchHeader';
import { ThermostatSetPointContainer } from './components/thermostat/setPointContainer';
import { ThermostatModeSelector } from './components/thermostat/modeSelector';
import { ThermostatFanSelector } from './components/thermostat/fanSelector';
import { AmbientTemperatureThermostatConfigModel, FanModeThermostatConfigModel, ModeThermostatConfigModel,
  SetPointThermostatConfigModel,
  SwitchThermostatConfigModel } from '../widgetDetailModels';
import { ThermostatSingleAmbientContainer } from './components/thermostat/singleAmbientContainer';


interface Props {
  switchConfig?: SwitchThermostatConfigModel;
  setPointConfig?: SetPointThermostatConfigModel;
  ambientConfig?: AmbientTemperatureThermostatConfigModel,
  fanModeConfig?: FanModeThermostatConfigModel,
  modeConfig?: ModeThermostatConfigModel,
  isThermostatEnabled: boolean;
}

export const ThermostatWidgetDetail: FC<Props> = ({
  switchConfig,
  setPointConfig,
  ambientConfig,
  fanModeConfig,
  modeConfig,
  isThermostatEnabled,
}) => {

  return (
    <View>
      <View style={styles.setSwitchWrapper}>
        {switchConfig &&
          <ThermostatSwitchHeader isThermostatEnabled={isThermostatEnabled} switchConfig={switchConfig} />}
      </View>
      <View style={styles.setPointWrapper}>
        {setPointConfig &&
          <ThermostatSetPointContainer 
            setPointConfig={setPointConfig} 
            ambientConfig={ambientConfig} 
            isThermostatEnabled={isThermostatEnabled}
          />}
        {!setPointConfig && ambientConfig && <ThermostatSingleAmbientContainer ambientConfig={ambientConfig} />}
      </View>
      <View style={styles.modesWrapper}>
        {isThermostatEnabled &&
          <>
            <View style={styles.modesPicker}>
              {modeConfig && <ThermostatModeSelector modeConfig={modeConfig} />}
            </View>
            <View style={styles.modesPicker}>
              {fanModeConfig && <ThermostatFanSelector fanModeConfig={fanModeConfig} />}
            </View>
          </>
        }
      </View>
    </View>
  );
};
