import { ShutterInfoTextOptionsModel } from './shutter/components/shutterModels';

export type BinaryDefaultValue = 'ON' | 'OFF';
export type TripleDefaultValue = 'ON' | 'OFF' | 'EMPTY';
export type WidgetDetailBinaryValue = 'ON' | 'OFF';

export interface WidgetDetailModel {
  id: string;
  title?: string;
  subtitle?: string;
  loadingInfoTextOptions?: LoadingInfoTextModel;
  value?: string;
  defaultValue?: string;
  onUpdateData?: (item: {id: string, value: string}) => void;
  loading?: boolean;
}

export interface DeviceItemModel {
  id: string;
  masterId: string;
  masterType: string;
  masterName: string;
  name: string;
  type: string;
  roomId: string;
  usage: string | null;
  isParent: boolean;
  link: string;
  state: string | number;
  options: DeviceOptionsModel | null;
}

export interface DeviceOptionsModel {
  minTemp: number;
  maxTemp: number;
  step: number;
  modes: number[];
  fanModes: number[];
}

export interface BinaryDoorWidgetDetailModel extends Omit<WidgetDetailModel, 'defaultValue' | 'value'>
{ defaultValue?: BinaryDefaultValue }

export interface TripleDoorWidgetDetailModel extends Omit<WidgetDetailModel, 'defaultValue' | 'value'>
{ defaultValue?: TripleDefaultValue }

export interface SwitchWidgetDetailModel extends Omit<WidgetDetailModel, 'defaultValue' | 'subtitle' | 'value'>
{ subtitle?: BinarySubtitleModel, value?: WidgetDetailBinaryValue }


export interface SwitchAndDimmerWidgetDetailModel extends Omit<WidgetDetailModel, 'defaultValue' | 'subtitle' | 'value'>
{
  subtitle?: BinarySubtitleModel,
  value?: number,
  sliderTitle?: string,
}

export interface GradualShutterWidgetDetailModel extends Omit<WidgetDetailModel, 'defaultValue' | 'subtitle' | 'title' | 'loadingInfoTextOptions'>
{
  widgetName?: string,
  widgetInfoTextOptions?: ShutterInfoTextOptionsModel,
  quickActionButtonsTextOptions?: QuickActionButtonsTextModel,
  quickActionsTitle?: string,
  controlPanelTitle?: string,
  loadingInfoTextOptions?: ShutterLoadingInfoTextModel,
}

export interface GradualShutterWithSlatsWidgetDetailModel extends Omit<WidgetDetailModel, 'id' | 'defaultValue' | 'subtitle' | 'title' | 'loadingInfoTextOptions' | 'value'>
{
  shutterId: string,
  slatsId: string,
  widgetName?: string,
  widgetInfoTextOptions?: ShutterInfoTextOptionsModel,
  quickActionButtonsTextOptions?: QuickActionButtonsTextModel,
  quickActionsTitle?: string,
  shutterValue?: string,
  slatsValue?: string,
  loadingInfoTextOptions?: ShutterLoadingInfoTextModel,
  shutterControlPanelTitle?: string,
  slatsControlPanelTitle?: string,
}

export interface ThermostatWidgetDetailModel extends Omit<WidgetDetailModel, | 'subtitle' | 'value'>
{
  value?: string | number,
  subtitle?: BinarySubtitleModel,
  setPointTitle?: string,
  setPointSubtitle?: string,
  modesTitle?: string,
  fanModesTitle?: string,
  childrenItems?: DeviceItemModel[];
  parentItem?: DeviceItemModel;
  options: DeviceOptionsModel;
  modesInfoText?: ModesInfoTextModel,
  speedsInfoText?: SpeedsInfoTextModel,
}

export interface LoadingInfoTextModel {
  option1?: string;
  option2?: string;
  option3?: string;
}

export interface ShutterLoadingInfoTextModel {
  opening?: string;
  closing?: string;
  stopping?: string;
}

export interface ModesInfoTextModel {
  hot?: string;
  cold?: string;
  auto?: string;
  fanOnly?: string;
  dry?: string;
}

export interface SpeedsInfoTextModel {
  off?: string;
  auto?: string;
  low?: string;
  medium?: string;
  fast?: string;
}

export interface QuickActionButtonsTextModel {
  open?: string;
  close?: string;
}

export interface BinarySubtitleModel {
  on?: string;
  off?: string;
}

export interface SettingDataOutputModel {
  id: string;
  value: string;
}

export interface OptionsConfigModel {
  label: string,
  value: number
}

export interface SwitchThermostatConfigModel {
  switchTitle: string;
  switchSubtitle: BinarySubtitleModel;
  switchLoadingTextOptions: LoadingInfoTextModel;
  switchIsLoading: boolean;
  switchVisible: boolean;
  onChangeSwitch: (val: boolean) => void;
}

export interface SetPointThermostatConfigModel {
  setPointId: string;
  setPointValue: string;
  setPointTitle: string;
  setPointSubtitle: string;
  setPointStep: number;
  setPointMinValue: number;
  setPointMaxValue: number;
  setPointIsLoading: boolean;
  onChangeSetPointValue: (value: SettingDataOutputModel) => void;
}

export interface AmbientTemperatureThermostatConfigModel {
  ambientTemperatureTitle: string;
  ambientTemperatureId: string;
  ambientTemperatureValue: string;
}

export interface FanModeThermostatConfigModel {
  fanModeId: string;
  fanModeValue: number;
  fanModeOptions: OptionsConfigModel[];
  fanModeSelectorTitle: string;
  fanModeSelectorPlaceholder: string;
  fanModeIsLoading: boolean;
  onChangeFanModeValue: (value: SettingDataOutputModel) => void;
}

export interface ModeThermostatConfigModel {
  modeId: string;
  modeValue: number;
  modeOptions: OptionsConfigModel[];
  modeSelectorTitle: string;
  modeSelectorPlaceholder: string;
  modeIsLoading: boolean;
  onChangeModeValue: (value: SettingDataOutputModel) => void;
}
