import type { DateNumberMonthNumberAndYear } from './calendarModel';
import { DayNumberOfTheWeek, GapsOfCalendarGrid, MonthNumber } from './calendarModel';
import { getDatesOfSelectedMonth } from './getDatesOfSelectedMonth';
import { getFirstDateOfMonthInDayWeek } from './getFirstDateOfMonthInDayWeek';

const TOTAL_NUMBER_OF_DAYS: GapsOfCalendarGrid = 42;
const FIRST_DAY_OF_WEEK: DayNumberOfTheWeek = 1;

interface DatesOfMonthList {
  datesOfPreviousMonthList: DateNumberMonthNumberAndYear[];
  datesOfCurrentMonthList: DateNumberMonthNumberAndYear[];
  datesOfNextMonthList: DateNumberMonthNumberAndYear[];
}

type GetDatesOfSelectedMonth = (monthNumber: MonthNumber, year: number) => DatesOfMonthList;

export const getDatesOfSelectedMonthList: GetDatesOfSelectedMonth = (monthNumber, year) => { 
  const { datesOfPreviousToMonth, datesOfCurrentToMonth } = getDatesOfSelectedMonth(monthNumber, year);
  const firstDateMonthInDayWeek = getFirstDateOfMonthInDayWeek(year, monthNumber);

  const gapsToFillThePreviousMonth = firstDateMonthInDayWeek ===  FIRST_DAY_OF_WEEK 
    ? FIRST_DAY_OF_WEEK 
    : firstDateMonthInDayWeek - 1 as DayNumberOfTheWeek;

  const datesOfPreviousMonthList = Array(gapsToFillThePreviousMonth).fill(0)
    .map((d, key) => ({
      dateNumber: datesOfPreviousToMonth - key,
      monthNumber,
      year,
    })).reverse() as DateNumberMonthNumberAndYear[];

  const datesOfCurrentMonthList = Array(datesOfCurrentToMonth).fill(0)
    .map((d, key) => ({
      dateNumber: key + 1,
      monthNumber,
      year,
    })) as DateNumberMonthNumberAndYear[];

  const gapsToFillTheAfterMonth = 
    TOTAL_NUMBER_OF_DAYS - datesOfPreviousMonthList.length - datesOfCurrentMonthList.length;
  
  const datesOfNextMonthList = Array(gapsToFillTheAfterMonth).fill(0)
    .map((d, key) => ({
      dateNumber: key + 1,
      monthNumber,
      year,
    })) as DateNumberMonthNumberAndYear[];

  return { 
    datesOfPreviousMonthList,
    datesOfCurrentMonthList,
    datesOfNextMonthList,
  };
};
